<?php
/*
Plugin Name: Mobilizer Plugin
Plugin URI: http://kartones.net/files/folders/php/default.aspx
Description: Mobile plugin and theme for wordpress using jquery mobile
Version: 1.0
Author: Kartones
Author URI: http://kartones.net/blogs/kartones/
Notes:
 * Check GetThemeRootPath and GetThemeRootUri methods below, as you need to set your own paths
 * You will need to modify the theme header.php file to your CSS path (or make it relative)
 * Same goes for site URLs inside templates. I have hardcoded paths, but you might want to use site_url(); instead
*/

class Mobilizer
{
	const MODE_MOBILE = 1;
	const MODE_NORMAL = 2;

	private static $cookieName = 'mobm';

	// Developer override flag
	// If set to a string, will search for matches and always activate for given IP requests.
	// Set to null to deactivate
	private static $devIpOverride = null;

	private $mode = self::MODE_NORMAL;

	/**
	 * Initializator. Sets mode (normal or mobile) and if request comes from a mobile,
	 * adds the correct hooks/filters to switch between modes
	 */
	public function Init()
	{
		if ($this->IsMobile())
		{
			$this->mode = $this->GetModeFromCookie();

			// Filters to hook to learned from WPTouch plugin (http://wordpress.org/extend/plugins/wptouch/)
			add_filter('stylesheet', array(&$this, 'GetStylesheetFolder'));
			add_filter('theme_root', array(&$this, 'GetThemeRootPath'));
			add_filter('theme_root_uri', array(&$this, 'GetThemeRootUri'));
			add_filter('template', array(&$this, 'GetTemplatesFolder'));
			add_action('wp_footer', array(&$this, 'AddFooterSwitcher'));
		}
	}

	/**
	 * Detects mobile devices (or the devIpOverride)
	 * @return boolean
	 */
	public function IsMobile()
	{
		if (self::$devIpOverride != null && strcmp($_SERVER['REMOTE_ADDR'], self::$devIpOverride) === 0)
		{
			return true;
		}
		if (isset($_SERVER['HTTP_X_WAP_PROFILE']) || isset($_SERVER['HTTP_PROFILE']))
		{
			return true;
		}
		if (strpos($_SERVER['HTTP_ACCEPT'], 'text/vnd.wap.wml') > 0
			|| strpos($_SERVER['HTTP_ACCEPT'], 'application/vnd.wap.xhtml+xml') > 0)
		{
			return true;
		}
		return (bool) preg_match("/(iphone|ipod|ipad|android|blackberry|kindle|iemobile|ppc|smartphone|windows phone|psp|symbian|smartphone|opera mini)/i",
					strtolower($_SERVER['HTTP_USER_AGENT']));
	}

	/**
	 * Reads stored mode from cookie. Defaults to mobile mode.
	 * @return integer self::MODE_XXX constant
	 */
	private function GetModeFromCookie()
	{
		if (isset($_COOKIE[self::$cookieName]) && $_COOKIE[self::$cookieName] == self::MODE_NORMAL)
		{
			return self::MODE_NORMAL;
		}
		return self::MODE_MOBILE;
	}

	/**
	 * Returns the javascript code to force switching between mobile and desktop in mobile devices
	 * @return string
	 */
	public function GetCookieModeSwitchJavascript()
	{
		return
			'<script type="text/javascript">function Switch() {' .
			'var expiration = new Date();expiration.setDate(expiration.getDate() + 365);' .
			'document.cookie = "' . self::$cookieName . '=' . 
			($this->mode == Mobilizer::MODE_NORMAL ? Mobilizer::MODE_MOBILE : Mobilizer::MODE_NORMAL) .
			'; expires="+expiration.toUTCString()+"; path=/";' .
			'}</script>';
	}

	/**
	 * Adds the footer switcher buttons (only if we are in a mobile device).
	 * Will be injected in the footer template.
	 */
	public function AddFooterSwitcher()
	{
		if ($this->mode == Mobilizer::MODE_MOBILE)
		{
			// Note: this call needs data-ajax=false to avoid JQuery Mobile intercepting it and not performing
			// both the onclick and href
			echo '<a href="http://www.darkmillenniumcodex.com',
				$_SERVER['REQUEST_URI'],
				'" onclick="Switch()" data-ajax="false">Switch to Desktop version</a>',
				$this->GetCookieModeSwitchJavascript();
		}
		else
		{
			echo '<a href="http://www.darkmillenniumcodex.com',
				$_SERVER['REQUEST_URI'],
				'" onclick="Switch()">Switch to Mobile version</a>&nbsp;&nbsp;&nbsp;&nbsp;',
				$this->GetCookieModeSwitchJavascript();
		}
	}

	/**
	 * Returns a different stylesheet folder for normal and mobile modes
	 * @param string $stylesheet
	 * @return string
	 */
	public function GetStylesheetFolder($stylesheet)
	{
		return ($this->mode == self::MODE_MOBILE) ? 'mobile' : $stylesheet;
	}

	/**
	 * Returns a different theme root path for normal and mobile modes
	 * @param string $path
	 * @return string
	 */
	public function GetThemeRootPath($path)
	{
		// Physical server path to the theme
		return ($this->mode == self::MODE_MOBILE) ?
			'C:\inetpub\xxxxxxxx/wp-content/plugins/mobilizer/themes' : $path;
	}

	/**
	 * Returns a different theme root uri for normal and mobile modes
	 * @param string $url
	 * @return string
	 */
	public function GetThemeRootUri($url)
	{
		// Full uri containing host to the theme
		return ($this->mode == self::MODE_MOBILE) ?
			'http://xxxxxxx/wp-content/plugins/mobilizer/themes' : $url;
	}

	/**
	 * Returns a different themplates path for normal and mobile modes
	 * @param string $template
	 * @return string
	 */
	public function GetTemplatesFolder($template)
	{
		return ($this->mode == self::MODE_MOBILE) ? 'mobile' : $template;
	}
}


// Ugly global variable, needed for the hook
global $mobilizerPlugin;
$mobilizerPlugin = new Mobilizer();

/**
 * Init function for WP hooks
 * @global Mobilizer $mobilizerPlugin
 */
function MobilizerInit()
{
	// Nothing to do if in admin interface
	if (!is_admin())
	{
		global $mobilizerPlugin;
		$mobilizerPlugin->Init();
	}
}

// Plugin initialization WP hooks
add_filter('plugins_loaded', 'MobilizerInit');

?>